@@ -15,10 +15,16 @@ def connection_cb(conn, request):
 
 def body_cb(data, conn, request):
     if not data:
+        if request.headers.get('x-requested-with', None) == 'XMLHttpRequest':
+            return conn.set_rmode_close(xhr_cb, [request])
         reader = HTTPClientReader(conn)
         reader.get_headers_only(response_headers_cb, [reader, request])
     else:
-        conn.write(data)
+        conn.write(data) # is this right?
+
+def xhr_cb(data, request):
+    request.write(data)
+    request.close()
 
 def response_headers_cb(response, reader, request):
     request.write(response.status_line + '\r\n')
