@@ -87,19 +87,22 @@ class Connection(object):
         self.halt_read()
         self.__read_buffer.reset()
         self.__clear_writes("Connection freed")
-        if self.pool and not self.__release_timer:
+        #if self.pool and not self.__release_timer:
+        if not self.__release_timer:
 #            raise "What?"
             self.__ready()
 #            self.__release_timer = event.timeout(timeout, self.__release_timer_cb)
-        else:            
+        else:
+            print 'pool',self.pool
+            print 'release_timer',self.__release_timer
             raise "What?"
+        
     def __release_timer_cb(self):
         self.__release_timer.delete()
         self.__release_timer = None
         self.pool.connection_available(self)
         
     def __ready(self):
-#        print 'connection ready'
         self.halt_read()
         self.__read_buffer.reset()
         self.__clear_writes("Connection freed")
@@ -117,6 +120,7 @@ class Connection(object):
 #            print 'no need for wevent.add: %s' % (self.wevent.pending(),)
     def set_rmode_size(self, size, cb, args=[]):
         self.mode = SizeReadMode(size, cb, args)
+        self.__mode_changed = True
         self.__start_read()
     
     def set_rmode_size_chunked(self, size, cb, args=[]):
